@@ -157,6 +157,10 @@ class Polynomial2D:
                     break
                 else:
                     newobj._sigclip(sigma_level)
+        else:
+            newobj._curvefit()
+            newobj.compute(rescale=False)
+            print('Sigma clipping = {0}'.format(doclip))
         if self.rescale['RESCALE'][0]:
             newobj.model['YFIT'] = self.rescale['Y'].invtransform(newobj.model['YFIT'])
         self.model = copy.deepcopy(newobj.model)
